/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global showPopup, closePopup, popupStatus, DEFAULT_PAGE, pageNow, backPage, changePage
 */

var addressbook,
    contacts;

function emptyElement(elm) {
    while (elm.firstChild) {
        elm.removeChild(elm.firstChild);
    }

    return elm;
}

function keyEventCB(event) {
    if (event.keyName === "back") {
        if (popupStatus === "Active") {
            closePopup();
        } else if (pageNow === DEFAULT_PAGE) {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (ignore) {

            }
        } else {
            backPage();
        }
    }
}

function setError(text) {
    console.log("Error : " + text);

    showPopup(text, "OK");
}

function showContact(index) {
    var objResult = emptyElement(document.querySelector("#contactDetail")),
        objTable,
        objRow,
        objCol,
        objImg,
        prop,
        data = {
            name: contacts[index].name.displayName,
            phone: ((contacts[index].phoneNumbers.length > 0) ? contacts[index].phoneNumbers[0].number : null),
            address: ((contacts[index].addresses.length > 0) ? contacts[index].addresses[0].streetAddress : null),
            email: ((contacts[index].emails.length > 0) ? contacts[index].emails[0].email : null),
            note: ((contacts[index].notes.length > 0) ? contacts[index].notes[0] : null),
            photo: contacts[index].photoURI || null
        };

    objTable = document.createElement("div");
    objTable.className = "contactTable";

    for (prop in data) {
        if (data.hasOwnProperty(prop) && data[prop] !== null) {
            objRow = document.createElement("div");
            objRow.className = "contactTableRow";

            objCol = document.createElement("div");
            objCol.className = "typeDetail";
            objCol.appendChild(document.createTextNode(prop));
            objRow.appendChild(objCol);

            objCol = document.createElement("div");
            objCol.className = "valueDetail";
            if (prop !== "photo") {
                objCol.appendChild(document.createTextNode(data[prop]));
            } else {
                objImg = document.createElement("img");
                objImg.className = "photoDetail";
                objImg.src = data[prop];
                objCol.appendChild(objImg);
            }
            objRow.appendChild(objCol);

            objTable.appendChild(objRow);
        }
    }

    objResult.appendChild(objTable);

    changePage("pageContact");
}

function createCallback(index) {
    var retFunc = function() {
        var data = {
            index: index
        };

        showContact(data.index);
    };

    return retFunc;
}

function showListView(dataArray) {
    var objResult = emptyElement(document.querySelector("#mainDetail")),
        objTable,
        objRow,
        objCol,
        i,
        prop;

    objTable = document.createElement("div");
    objTable.className = "resultTable";

    if (dataArray.length > 0) {
        for (i = 0; i < dataArray.length; i++) {
            objRow = document.createElement("div");

            objRow.className = "resultTableRow";
            for (prop in dataArray[i]) {
                if (dataArray[i].hasOwnProperty(prop)) {
                    objCol = document.createElement("div");
                    objCol.className = prop + "Detail";
                    if (dataArray[i][prop].hasOwnProperty("data")) {
                        objCol.appendChild(document.createTextNode(dataArray[i][prop].data));
                    }
                    if (dataArray[i][prop].hasOwnProperty("cb")) {
                        objCol.addEventListener("click", dataArray[i][prop].cb);
                    }

                    objRow.appendChild(objCol);
                }
            }

            objTable.appendChild(objRow);
        }
    } else {
        objRow = document.createElement("div");
        objRow.className = "resultTableError";
        objRow.appendChild(document.createTextNode("No Data"));

        objTable.appendChild(objRow);
    }

    objResult.appendChild(objTable);
}

function setDefaultViews() {
    var defaultErrorMessage = document.querySelector("#errorMessage"),
        dataContacts = [],
        i;

    for (i = 0; i < contacts.length; i++) {
        dataContacts.push({
            name: {
                data: contacts[i].name.displayName,
                cb: createCallback(i)
            }
        });
    }

    showListView(dataContacts);

    defaultErrorMessage.style.display = "none";
}

function setDefaultVariables() {
    if (window.tizen && tizen.contact && tizen.contact.getAddressBooks) {
        try {
            addressbook = tizen.contact.getDefaultAddressBook();
            addressbook.find(function(result) {
                contacts = result;
                setDefaultViews();
            }, function() {
                setError("Failed to get contacts");
            });
        } catch (err) {
            return false;
        }

        return true;
    }

    return false;
}

function setDefaultEvents() {
    document.addEventListener("tizenhwkey", keyEventCB);

    return true;
}

function init() {
    if (setDefaultEvents() && setDefaultVariables()) {
        console.log("App: init");
    } else {
        setError("getContactList failed.");
    }
}

window.onload = init;